==> activity-center-biz-1.0.2-20160622.061036-30-sources.jar: cn/com/duiba/activity/center/biz/service/seconds_kill/impl/DuibaSecondsKillActivityBrickServiceImpl.java <==
package cn.com.duiba.activity.center.biz.service.seconds_kill.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.seconds_kill.DuibaSecondsKillActivityBrickDto;
import cn.com.duiba.activity.center.biz.dao.seconds_kill.DuibaSecondsKillActivityBrickDao;
import cn.com.duiba.activity.center.biz.entity.seconds_kill.DuibaSecondsKillActivityBrickEntity;
import cn.com.duiba.activity.center.biz.service.seconds_kill.DuibaSecondsKillActivityBrickService;
import cn.com.duiba.wolf.utils.BeanUtils;

@Service
public class DuibaSecondsKillActivityBrickServiceImpl implements
		DuibaSecondsKillActivityBrickService {
	
	@Autowired
	private DuibaSecondsKillActivityBrickDao duibaSecondsKillActivityBrickDao;

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findPage(Map<String, Object> paramMap) {
		return BeanUtils.copyList(duibaSecondsKillActivityBrickDao.findPage(paramMap), DuibaSecondsKillActivityBrickDto.class);
	}

	@Override
	public Long findPageCount() {
		return duibaSecondsKillActivityBrickDao.findPageCount();
	}

	@Override
	public DuibaSecondsKillActivityBrickDto find(Long id) {
		return BeanUtils.copy(duibaSecondsKillActivityBrickDao.find(id), DuibaSecondsKillActivityBrickDto.class);
	}

	@Override
	public void insert(DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickDao.insert(BeanUtils.copy(duibaSecondsKillActivityBrick, DuibaSecondsKillActivityBrickEntity.class));
	}

	@Override
	public void update(DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickDao.update(BeanUtils.copy(duibaSecondsKillActivityBrick, DuibaSecondsKillActivityBrickEntity.class));
	}

	@Override
	public void open(Long id) {
		duibaSecondsKillActivityBrickDao.open(id);
	}

	@Override
	public void disable(Long id) {
		duibaSecondsKillActivityBrickDao.disable(id);
	}

	@Override
	public DuibaSecondsKillActivityBrickDto findByTitle(String title) {
		return BeanUtils.copy(duibaSecondsKillActivityBrickDao.findByTitle(title), DuibaSecondsKillActivityBrickDto.class);
	}

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findAllEnable() {
		return BeanUtils.copyList(duibaSecondsKillActivityBrickDao.findAllEnable(), DuibaSecondsKillActivityBrickDto.class);
	}

}

==> activity-center-biz-1.0.2-20160701.054452-45-sources.jar: cn/com/duiba/activity/center/biz/service/seconds_kill/impl/DuibaSecondsKillActivityBrickServiceImpl.java <==
package cn.com.duiba.activity.center.biz.service.seconds_kill.impl;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import cn.com.duiba.activity.center.api.dto.seconds_kill.DuibaSecondsKillActivityBrickDto;
import cn.com.duiba.activity.center.biz.dao.seconds_kill.DuibaSecondsKillActivityBrickDao;
import cn.com.duiba.activity.center.biz.entity.seconds_kill.DuibaSecondsKillActivityBrickEntity;
import cn.com.duiba.activity.center.biz.service.seconds_kill.DuibaSecondsKillActivityBrickService;
import cn.com.duiba.wolf.utils.BeanUtils;

@Service
public class DuibaSecondsKillActivityBrickServiceImpl implements
		DuibaSecondsKillActivityBrickService {
	
	@Autowired
	private DuibaSecondsKillActivityBrickDao duibaSecondsKillActivityBrickDao;

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findPage(Map<String, Object> paramMap) {
		return BeanUtils.copyList(duibaSecondsKillActivityBrickDao.findPage(paramMap), DuibaSecondsKillActivityBrickDto.class);
	}

	@Override
	public Long findPageCount() {
		return duibaSecondsKillActivityBrickDao.findPageCount();
	}

	@Override
	public DuibaSecondsKillActivityBrickDto find(Long id) {
		return BeanUtils.copy(duibaSecondsKillActivityBrickDao.find(id), DuibaSecondsKillActivityBrickDto.class);
	}

	@Override
	public void insert(DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		DuibaSecondsKillActivityBrickEntity entity = BeanUtils.copy(duibaSecondsKillActivityBrick, DuibaSecondsKillActivityBrickEntity.class);
		duibaSecondsKillActivityBrickDao.insert(entity);
		duibaSecondsKillActivityBrick.setId(entity.getId());
	}

	@Override
	public void update(DuibaSecondsKillActivityBrickDto duibaSecondsKillActivityBrick) {
		duibaSecondsKillActivityBrickDao.update(BeanUtils.copy(duibaSecondsKillActivityBrick, DuibaSecondsKillActivityBrickEntity.class));
	}

	@Override
	public void open(Long id) {
		duibaSecondsKillActivityBrickDao.open(id);
	}

	@Override
	public void disable(Long id) {
		duibaSecondsKillActivityBrickDao.disable(id);
	}

	@Override
	public DuibaSecondsKillActivityBrickDto findByTitle(String title) {
		return BeanUtils.copy(duibaSecondsKillActivityBrickDao.findByTitle(title), DuibaSecondsKillActivityBrickDto.class);
	}

	@Override
	public List<DuibaSecondsKillActivityBrickDto> findAllEnable() {
		return BeanUtils.copyList(duibaSecondsKillActivityBrickDao.findAllEnable(), DuibaSecondsKillActivityBrickDto.class);
	}

}
